==> tetzle_2.1.6.orig.tar.gz: tetzle-2.1.6/translations/tetzle_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>פתיחת תמונה</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>שיפוע גבולות</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>הטלת צללים</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>צבעים</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>רקע אחורי:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>צל:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>הדגשה:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>תמונה חסרה.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>אנא המתן</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>כעת טוען תמונה...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>כעת מפיק פאזל...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>כעת יוצר חתיכות...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>כעת טוען פאזל...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>פורמט מידע לא מוכר</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>אלמנט לא מוכר &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>שגיאת ניתוח קובץ XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>כעת טוען חתיכות...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>כעת מאחזר חתיכות...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>כעת ממקם חתיכות...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>בחירת משחק</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>משחק נוכחי</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>מאפייני תמונה</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>תגיות:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>הוספת תמונה</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>הסרת תמונה</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>מאפייני תמונה</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 חתיכות</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>מעתיק תמונה כעת...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>הסרת תמונה נבחרת?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>ללא כותרת</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>ללא כותרת</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>מחיקת משחק</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>מחיקת משחק נוכחי?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>סקירה כללית</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>הוסף תגית</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>הסר תגית</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>לא מתויג</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>כל התמונות</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>ללא כותרת %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>להסיר תגית נבחרת?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>סליחה</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>תגית בשם זה כבר קיימת.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;אחזור חתיכות</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;בחירה...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;תצוגה</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>זום &amp;חוצה</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>התאמה &amp;מיטבית</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;מראה...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;שפה...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;בקרים</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;QT</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>קליק שמאלי או רווח</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;בחירת חתיכות:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;סיבוב חתיכות:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>קליק ימני, Control + קליק שמאלי, או R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>קליק אמצעי, Shift + קליק שמאלי, או חצים</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>גלגל עכבר או +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>הזזת עכבר או W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>אודות Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>פתיחת תמונה</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>מראה</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>שיפוע גבולות</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>הטלת צללים</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>צבעים</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>רקע אחורי:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>צל:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>הדגשה:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>תמונה חסרה.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>אנא המתן</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>כעת טוען תמונה...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>כעת מפיק פאזל...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>כעת יוצר חתיכות...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>כעת טוען פאזל...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>פורמט מידע לא מוכר</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>אלמנט לא מוכר &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>שגיאת ניתוח קובץ XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>כעת טוען חתיכות...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>כעת מאחזר חתיכות...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>כעת ממקם חתיכות...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>בחירת משחק</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>משחק נוכחי</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>מאפייני תמונה</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>תגיות:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחר שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>הוספת תמונה</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>הסרת תמונה</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>מאפייני תמונה</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 חתיכות</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>מעתיק תמונה כעת...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>ללא כותרת</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>ללא כותרת</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>מחיקת משחק</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>מחיקת משחק נוכחי?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>סקירה כללית</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>הוסף תגית</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>הסר תגית</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>לא מתויג</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>כל התמונות</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>ללא כותרת %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>להסיר תגית נבחרת?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>סליחה</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>תגית בשם זה כבר קיימת.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;אחזור חתיכות</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;בחירה...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;תצוגה</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>זום &amp;חוצה</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>התאמה &amp;מיטבית</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;מראה...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;שפה...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;בקרים</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;QT</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>קליק שמאלי או רווח</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;בחירת חתיכות:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;סיבוב חתיכות:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>קליק ימני, Control + קליק שמאלי, או R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>קליק אמצעי, Shift + קליק שמאלי, או חצים</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>גלגל עכבר או +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>הזזת עכבר או W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>אודות Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
